#include <iostream>
#include <vector>
#include "histogram.h"
#include "text.h"
#include "svg.h"
using namespace std;

struct Input {
    vector<double> numbers;
    size_t bin_count = 0;
};

Input input_data() {
    Input in;
    int number_count;

    do {
        cerr << "Enter number count: ";
        cin >> number_count;
    } while (number_count < 1);

    do {
        cerr << "Enter bucket: ";
        cin >> in.bin_count;
    } while (in.bin_count < 1);

    cerr << "\n";

    in.numbers.resize(number_count);
    for (int i = 0; i < number_count; i++) {
        cin >> in.numbers[i];
    }

    return in;
}

void show_histogram_svg(const vector<size_t>& bins) {
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;

    svg_begin(IMAGE_WIDTH, IMAGE_HEIGHT);

    size_t max_count = 0;
    for (size_t count : bins) {
        if (count > max_count) max_count = count;
    }

    double top = 0;
    for (size_t bin : bins) {
        const double bin_width = (max_count > 0) ?
            (static_cast<double>(bin) / max_count * (IMAGE_WIDTH - TEXT_WIDTH)) : 0;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, "black", "#aaffaa");
        top += BIN_HEIGHT;
    }

    svg_end();
}

int main() {
    auto input = input_data();
    auto bins = make_histogram(input.numbers, input.bin_count);
    show_histogram_svg(bins);
    return 0;
}
